## v0.5.2 (2025-05-20)

### Fix

- **authentication.py**: remove support to load settings from .env (#3)

[main 0d63496] bump: version 0.5.1 → 0.5.2
 3 files changed, 8 insertions(+), 2 deletions(-)

